@@ -14,6 +14,8 @@
 #import "Playlist.h"
 #import "Directory.h"
 
+#include "mtp-utils.h"
+
 @interface NJB : NSObject {
 	IBOutlet StatusDisplayer *statusDisplayer;
 	njb_t *njb;
@@ -28,11 +30,18 @@
 	BOOL downloadingTracks;
 	njb_t njbs[NJB_MAX_DEVICES];
 	BOOL turbo;
+	BOOL mtpDevice;
 	
 	NSString *deviceString;
 	NSString *firmwareVersionString;
 	NSString *deviceIDString;
 	NSString *deviceVersionString;
+	
+	PTPParams params;
+	PTP_USB ptp_usb;
+	uint8_t interfaceNumber;
+	int batteryLevelMax;
+	unsigned storageID;
 }
 
 - (NJBTransactionResult *)connect;
@@ -76,7 +85,9 @@
 - (int)batteryLevel;
 - (NSString *)batteryStatus;
 - (void)setTurbo:(BOOL) newTurbo;
+- (int)batteryLevelMax;
 
 int progress (u_int64_t sent, u_int64_t total, const char* buf, unsigned len, void *data);
+int progressPTP(u_int32_t sent, u_int32_t total);
 
 @end
