@@ -13,6 +13,7 @@
  * changes for daylight saving. Could be confusing though.
  */
 
+#import "defs.h"
 #import "SettingsTab.h"
 
 @implementation SettingsTab
@@ -92,7 +93,7 @@
 																							 withRunInMainThread:YES];
 	[updateDisplay setDisplayStatus:NO];
 	
-	NSString *description = @"Getting Jukebox settings";
+	NSString *description = NSLocalizedString(@"Getting Jukebox settings", nil);
 	[self addToQueue:getSettings withSubItems:[NSArray arrayWithObjects:updateDisplay, nil] withDescription:description];
 	[getSettings release];
 	[updateDisplay release];
@@ -199,14 +200,14 @@
 																												withObject:owner];
 	[setOwner setStatus:STATUS_UPDATING_SETTINGS];
 	
-	[self addToQueue:setOwner withSubItems:nil withDescription:[NSString stringWithFormat:@"Setting Owner String To %@", owner]];
+	[self addToQueue:setOwner withSubItems:nil withDescription:[NSString stringWithFormat:NSLocalizedString(@"Setting Owner String To %@", nil), owner]];
 	[setOwner release];
 		
 	NJBQueueItem *setTime = [[NJBQueueItem alloc] initWithTarget:theNJB withSelector:@selector(setTime:)
 																										withObject:[NSNumber numberWithDouble:jukeboxTimeInterval]];
 	[setTime setStatus:STATUS_UPDATING_SETTINGS];
 	
-	[self addToQueue:setTime withSubItems:nil withDescription:[NSString stringWithFormat:@"Setting Time To %@", time]];
+	[self addToQueue:setTime withSubItems:nil withDescription:[NSString stringWithFormat:NSLocalizedString(@"Setting Time To %@", nil), time]];
 	[setTime release];
 	
 	/*if (bitmapPath != nil)
