@@ -133,56 +133,56 @@
 	switch (status)
 	{
 		case STATUS_CONNECTED:
-			return [NSString stringWithString:@"Connected"];
+			return [NSString stringWithString:NSLocalizedString(@"Connected", nil)];
 		case STATUS_DISCONNECTED:
-			return [NSString stringWithString:@"Disconnected"];
+			return [NSString stringWithString:NSLocalizedString(@"Disconnected", nil)];
 		case STATUS_NO_NJB:
-			return [NSString stringWithString:@"No NJB Devices Found"];
+			return [NSString stringWithString:NSLocalizedString(@"No NJB Devices Found", nil)];
 		case STATUS_IDLE:
 			// return a copy of the idle string: this will get set back to the idle string later releasing the old one!
 			return [NSString stringWithString:[self idleString]];
 		case STATUS_COULD_NOT_OPEN:
-			return [NSString stringWithString:@"Could Not Open NJB"];
+			return [NSString stringWithString:NSLocalizedString(@"Could Not Open NJB", nil)];
 		case STATUS_COULD_NOT_CAPTURE:
-			return [NSString stringWithString:@"Could Not Capture NJB"];
+			return [NSString stringWithString:NSLocalizedString(@"Could Not Capture NJB", nil)];
 		case STATUS_UPLOADING_TRACK:
-			return [NSString stringWithString:@"Uploading Track"];
+			return [NSString stringWithString:NSLocalizedString(@"Uploading Track", nil)];
 		case STATUS_UPLOADING_FILE:
-			return [NSString stringWithString:@"Uploading File"];
+			return [NSString stringWithString:NSLocalizedString(@"Uploading File", nil)];
 		case STATUS_DOWNLOADING_TRACK_LIST:
-			return [NSString stringWithString:@"Downloading Track List"];
+			return [NSString stringWithString:NSLocalizedString(@"Downloading Track List", nil)];
 		case STATUS_DOWNLOADING_FILE_LIST:
-			return [NSString stringWithString:@"Downloading File List"];
+			return [NSString stringWithString:NSLocalizedString(@"Downloading File List", nil)];
 		case STATUS_UPDATING_TRACK_TAG:
-			return [NSString stringWithString:@"Updating Track Tag"];
+			return [NSString stringWithString:NSLocalizedString(@"Updating Track Tag", nil)];
 		case STATUS_DOWNLOADING_TRACK:
-			return [NSString stringWithString:@"Downloading Track"];
+			return [NSString stringWithString:NSLocalizedString(@"Downloading Track", nil)];
 		case STATUS_DELETING_TRACK:
-			return [NSString stringWithString:@"Deleting Track"];
+			return [NSString stringWithString:NSLocalizedString(@"Deleting Track", nil)];
 		case STATUS_DOWNLOADING_FILE:
-			return [NSString stringWithString:@"Downloading File"];
+			return [NSString stringWithString:NSLocalizedString(@"Downloading File", nil)];
 		case STATUS_CONNECTING:
-			return [NSString stringWithString:@"Connecting"];
+			return [NSString stringWithString:NSLocalizedString(@"Connecting", nil)];
 		case STATUS_DISCONNECTING:
-			return [NSString stringWithString:@"Disconnecting"];
+			return [NSString stringWithString:NSLocalizedString(@"Disconnecting", nil)];
 		case STATUS_DELETING_FILE:
-			return [NSString stringWithString:@"Deleting File"];
+			return [NSString stringWithString:NSLocalizedString(@"Deleting File", nil)];
 		case STATUS_DOWNLOADING_SETTINGS:
-			return [NSString stringWithString:@"Downloading Jukebox Settings"];
+			return [NSString stringWithString:NSLocalizedString(@"Downloading Jukebox Settings", nil)];
 		case STATUS_UPDATING_SETTINGS:
-			return [NSString stringWithString:@"Updating Jukebox Settings"];
+			return [NSString stringWithString:NSLocalizedString(@"Updating Jukebox Settings", nil)];
 		case STATUS_DOWNLOADING_PLAYLISTS:
-			return [NSString stringWithString:@"Downloading Playlists"];
+			return [NSString stringWithString:NSLocalizedString(@"Downloading Playlists", nil)];
 		case STATUS_UPDATING_PLAYLIST:
-			return [NSString stringWithString:@"Updating Playlist"];
+			return [NSString stringWithString:NSLocalizedString(@"Updating Playlist", nil)];
 		case STATUS_DELETING_PLAYLIST:
-			return [NSString stringWithString:@"Deleting Playlist"];
+			return [NSString stringWithString:NSLocalizedString(@"Deleting Playlist", nil)];
 		case STATUS_CREATING_FOLDER:
-			return [NSString stringWithString:@"Creating Folder"];
+			return [NSString stringWithString:NSLocalizedString(@"Creating Folder", nil)];
 		case STATUS_UNKNOWN:
 		default:
 			NSLog(@"Unknown status %d in StatusDisplayer.statusStringForStatus", status);
-			return [NSString stringWithString:@"Unknown Status"];
+			return [NSString stringWithString:NSLocalizedString(@"Unknown Status", nil)];
 	}
 }
 
