@@ -23,7 +23,7 @@ typedef enum _codecTypes {CODEC_UNDEFINED = -1, CODEC_MP3 = 0, CODEC_WMA = 1, CO
 	unsigned trackNumber;
 	unsigned year;
 	codecTypes codec;
-	unsigned filesize;
+	unsigned long long filesize;
 }
 - (id)initWithTrack:(Track *)track;
 - (NSString *)title;
