@@ -14,7 +14,7 @@
 #define __LIBNJB__H
 
 /** The version of this installation of libnjb */
-#define LIBNJB_VERSION 2.2.3
+#define LIBNJB_VERSION "2.2.4"
 /** A legacy definition - nowadays we always compile for libusb */
 #define LIBNJB_COMPILED_FOR_LIBUSB 1
 
@@ -82,6 +82,8 @@ typedef unsigned __int64 u_int64_t;
 #define NJB_DEVICE_DELLDJ2	0x0a /**< Second Generation Dell DJ */
 #define NJB_DEVICE_POCKETDJ     0x0b /**< Dell Pocket DJ */
 #define NJB_DEVICE_ZENSLEEK	0x0c /**< Zen Sleek */
+#define NJB_DEVICE_CREATIVEZEN  0x0d /**< Creative Zen (Micro variant) */
+#define NJB_DEVICE_DELLDJ3      0x0e /**< Third Generation Dell DJ */
 /** @} */
 
 /**
@@ -152,6 +154,7 @@ typedef unsigned __int64 u_int64_t;
  */
 #define NJB_TURBO_OFF   0 /**< turbo mode is off for series 3 devices */
 #define NJB_TURBO_ON    1 /**< turbo mode is on for series 3 devices */
+/** @} */
 
 /** The fixed length of the owner string */
 #define OWNER_STRING_LENGTH	128
@@ -541,6 +544,7 @@ void NJB_Reset_Get_Datafile_Tag (njb_t *njb);
 njb_datafile_t *NJB_Get_Datafile_Tag (njb_t *njb);
 void NJB_Datafile_Destroy(njb_datafile_t *df);
 #define NJB_Get_File NJB_Get_Track
+#define NJB_Get_File_fd NJB_Get_Track_fd
 int NJB_Send_File (njb_t *njb, const char *path, const char *name, const char *folder,
 	NJB_Xfer_Callback *callback, void *data, u_int32_t *fileid);
 int NJB_Delete_Datafile (njb_t *njb, u_int32_t fileid);
